@@ -3,7 +3,7 @@
 #' This function generates the \eqn{d}-dimensional unit simplex in H- or V-representation.
 #' 
 #' @param dimension The dimension of the unit simplex.
-#' @param representation A string to declare the representation. It has to be \code{'H'} for H-representation or \code{'V'} for V-representation.
+#' @param representation A string to declare the representation. It has to be \code{'H'} for H-representation or \code{'V'} for V-representation.  Default valus is 'H'.
 #' 
 #' @return A polytope class representing the \eqn{d}-dimensional unit simplex in H- or V-representation.
 #' @examples
@@ -13,7 +13,7 @@
 #' # generate a 20-dimensional simplex in V-representation
 #' P = gen_simplex(20, 'V')
 #' @export
-gen_simplex <- function(dimension, representation) {
+gen_simplex <- function(dimension, representation = 'H') {
   
   kind_gen = 3
   m_gen = 0
@@ -28,13 +28,13 @@ gen_simplex <- function(dimension, representation) {
   Mat = poly_gen(kind_gen, Vpoly_gen, FALSE, dimension, m_gen)
 
   # first column is the vector b
-  b = Mat[,1]
-  Mat = Mat[,-c(1)]
+  b = Mat[, 1]
+  Mat = Mat[, -c(1), drop = FALSE]
   
   if (Vpoly_gen) {
-    P = Vpolytope$new(Mat,  1/prod(1:dimension))
+    P = Vpolytope(V = Mat, volume = 1/prod(1:dimension))
   } else {
-    P = Hpolytope$new(-Mat, b,  1/prod(1:dimension))
+    P = Hpolytope(A = -Mat, b = b, volume = 1/prod(1:dimension))
   }
   
   return(P)
