@@ -89,11 +89,12 @@ void sample_from_polytope(Polytope &P, RNGType &rng, PointList &randPoints, unsi
 //' @param random_walk Optional. A list that declares the random walk and some related parameters as follows:
 //' \itemize{
 //' \item{\code{walk} }{ A string to declare the random walk: i) \code{'CDHR'} for Coordinate Directions Hit-and-Run, ii) \code{'RDHR'} for Random Directions Hit-and-Run, iii) \code{'BaW'} for Ball Walk, iv) \code{'BiW'} for Billiard walk, v) \code{'BCDHR'} boundary sampling by keeping the extreme points of CDHR or vi) \code{'BRDHR'} boundary sampling by keeping the extreme points of RDHR. The default walk is \code{'BiW'} for the uniform distribution or \code{'CDHR'} for the Gaussian distribution.}
-//' \item{\code{walk_length} }{ The number of the steps per generated point for the random walk. The default value is \eqn{5} for \code{'BiW'} and \eqn{\lfloor 10 + d/10\rfloor} otherwise.}
+//' \item{\code{walk_length} }{ The number of the steps per generated point for the random walk. The default value is 1.}
 //' \item{\code{nburns} }{ The number of points to burn before start sampling.}
 //' \item{\code{starting_point} }{ A \eqn{d}-dimensional numerical vector that declares a starting point in the interior of the polytope for the random walk. The default choice is the center of the ball as that one computed by the function \code{inner_ball()}.}
 //' \item{\code{BaW_rad} }{ The radius for the ball walk.}
 //' \item{\code{L} }{ The maximum length of the billiard trajectory.}
+//' \item{\code{seed} }{ A fixed seed for the number generator.}
 //' }
 //' @param distribution Optional. A list that declares the target density and some related parameters as follows:
 //' \itemize{
@@ -101,7 +102,6 @@ void sample_from_polytope(Polytope &P, RNGType &rng, PointList &randPoints, unsi
 //' \item{\code{variance} }{ The variance of the multidimensional spherical gaussian. The default value is 1.}
 //'  \item{\code{mode} }{ A \eqn{d}-dimensional numerical vector that declares the mode of the Gaussian distribution. The default choice is the center of the as that one computed by the function \code{inner_ball()}.}
 //' }
-//' @param seed Optional. A fixed seed for the number generator.
 //'
 //' @return A \eqn{d\times n} matrix that contains, column-wise, the sampled points from the convex polytope P.
 //' @examples
@@ -112,7 +112,7 @@ void sample_from_polytope(Polytope &P, RNGType &rng, PointList &randPoints, unsi
 //' # gaussian distribution from the 2d unit simplex in H-representation with variance = 2
 //' A = matrix(c(-1,0,0,-1,1,1), ncol=2, nrow=3, byrow=TRUE)
 //' b = c(0,0,1)
-//' P = Hpolytope$new(A,b)
+//' P = Hpolytope(A = A, b = b)
 //' points = sample_points(P, n = 100, distribution = list("density" = "gaussian", "variance" = 2))
 //'
 //' # uniform points from the boundary of a 2-dimensional random H-polytope
@@ -121,11 +121,10 @@ void sample_from_polytope(Polytope &P, RNGType &rng, PointList &randPoints, unsi
 //'
 //' @export
 // [[Rcpp::export]]
-Rcpp::NumericMatrix sample_points(Rcpp::Nullable<Rcpp::Reference> P,
-                                  Rcpp::Nullable<unsigned int> n,
+Rcpp::NumericMatrix sample_points(Rcpp::Reference P,
+                                  int n,
                                   Rcpp::Nullable<Rcpp::List> random_walk = R_NilValue,
-                                  Rcpp::Nullable<Rcpp::List> distribution = R_NilValue,
-                                  Rcpp::Nullable<double> seed = R_NilValue){
+                                  Rcpp::Nullable<Rcpp::List> distribution = R_NilValue){
 
     typedef double NT;
     typedef Cartesian<NT>    Kernel;
@@ -138,12 +137,29 @@ Rcpp::NumericMatrix sample_points(Rcpp::Nullable<Rcpp::Reference> P,
     typedef Eigen::Matrix<NT,Eigen::Dynamic,1> VT;
     typedef Eigen::Matrix<NT,Eigen::Dynamic,Eigen::Dynamic> MT;
 
-    unsigned int type = Rcpp::as<Rcpp::Reference>(P).field("type"),dim = Rcpp::as<Rcpp::Reference>(P).field("dimension"),
-          walkL = 10 + dim / 10;
+    unsigned int dim, walkL = 1, type_num;
+
+    std::string type = Rcpp::as<std::string>(P.slot("type"));
+
+    if (type.compare(std::string("Hpolytope")) == 0) {
+        dim = Rcpp::as<MT>(P.slot("A")).cols();
+        type_num = 1;
+    } else if (type.compare(std::string("Vpolytope")) == 0) {
+        dim = Rcpp::as<MT>(P.slot("V")).cols();
+        type_num = 2;
+    } else if (type.compare(std::string("Zonotope")) == 0) {
+        dim = Rcpp::as<MT>(P.slot("G")).cols();
+        type_num = 3;
+    } else if (type.compare(std::string("VpolytopeIntersection")) == 0) {
+        dim = Rcpp::as<MT>(P.slot("V1")).cols();
+        type_num = 4;
+    } else {
+        throw Rcpp::exception("Unknown polytope representation!");
+    }
 
     RNGType rng(dim);
-    if (seed.isNotNull()) {
-        unsigned seed2 = Rcpp::as<double>(seed);
+    if (Rcpp::as<Rcpp::List>(random_walk).containsElementNamed("seed")) {
+        unsigned seed2 = Rcpp::as<double>(Rcpp::as<Rcpp::List>(random_walk)["seed"]);
         rng.set_seed(seed2);
     }
 
@@ -160,7 +176,7 @@ Rcpp::NumericMatrix sample_points(Rcpp::Nullable<Rcpp::Reference> P,
     std::pair<Point, NT> InnerBall;
     Point mode(dim);
 
-    numpoints = Rcpp::as<unsigned int>(n);
+    numpoints = n;
     if (numpoints <= 0) throw Rcpp::exception("The number of samples has to be a positice integer!");
 
     if (!distribution.isNotNull() || !Rcpp::as<Rcpp::List>(distribution).containsElementNamed("density")) {
@@ -198,14 +214,13 @@ Rcpp::NumericMatrix sample_points(Rcpp::Nullable<Rcpp::Reference> P,
 
     if (!random_walk.isNotNull() || !Rcpp::as<Rcpp::List>(random_walk).containsElementNamed("walk")) {
         if (gaussian) {
-            if (type == 1) {
+            if (type_num == 1) {
                 cdhr = true;
             } else {
                 rdhr = true;
             }
         } else {
             billiard = true;
-            walkL = 5;
         }
     } else if (Rcpp::as<std::string>(Rcpp::as<Rcpp::List>(random_walk)["walk"]).compare(std::string("CDHR")) == 0) {
         cdhr = true;
@@ -224,7 +239,6 @@ Rcpp::NumericMatrix sample_points(Rcpp::Nullable<Rcpp::Reference> P,
     } else if (Rcpp::as<std::string>(Rcpp::as<Rcpp::List>(random_walk)["walk"]).compare(std::string("BiW")) == 0) {
         if (gaussian) throw Rcpp::exception("Billiard walk can be used only for uniform sampling!");
         billiard = true;
-        walkL = 5;
         if (Rcpp::as<Rcpp::List>(random_walk).containsElementNamed("L")) {
             L = Rcpp::as<NT>(Rcpp::as<Rcpp::List>(random_walk)["L"]);
             set_L = true;
@@ -234,11 +248,11 @@ Rcpp::NumericMatrix sample_points(Rcpp::Nullable<Rcpp::Reference> P,
         if (gaussian) throw Rcpp::exception("Gaussian sampling from the boundary is not supported!");
         rdhr = true;
         boundary = true;
-    }else if (Rcpp::as<std::string>(Rcpp::as<Rcpp::List>(random_walk)["walk"]).compare(std::string("BCDHR")) == 0) {
+    } else if (Rcpp::as<std::string>(Rcpp::as<Rcpp::List>(random_walk)["walk"]).compare(std::string("BCDHR")) == 0) {
         if (gaussian) throw Rcpp::exception("Gaussian sampling from the boundary is not supported!");
         cdhr = true;
         boundary = true;
-    }else {
+    } else {
         throw Rcpp::exception("Unknown walk type!");
     }
 
@@ -268,11 +282,11 @@ Rcpp::NumericMatrix sample_points(Rcpp::Nullable<Rcpp::Reference> P,
         }
     }
 
-    switch(type) {
+    switch(type_num) {
         case 1: {
             // Hpolytope
-            HP.init(dim, Rcpp::as<MT>(Rcpp::as<Rcpp::Reference>(P).field("A")),
-                    Rcpp::as<VT>(Rcpp::as<Rcpp::Reference>(P).field("b")));
+            HP.init(dim, Rcpp::as<MT>(P.slot("A")),
+                    Rcpp::as<VT>(P.slot("b")));
 
             if (!set_starting_point || (!set_mode && gaussian)) {
                 InnerBall = HP.ComputeInnerBall();
@@ -291,8 +305,8 @@ Rcpp::NumericMatrix sample_points(Rcpp::Nullable<Rcpp::Reference> P,
         }
         case 2: {
             // Vpolytope
-            VP.init(dim, Rcpp::as<MT>(Rcpp::as<Rcpp::Reference>(P).field("V")),
-                    VT::Ones(Rcpp::as<MT>(Rcpp::as<Rcpp::Reference>(P).field("V")).rows()));
+            VP.init(dim, Rcpp::as<MT>(P.slot("V")),
+                    VT::Ones(Rcpp::as<MT>(P.slot("V")).rows()));
 
             if (!set_starting_point || (!set_mode && gaussian)) {
                 InnerBall = VP.ComputeInnerBall();
@@ -309,8 +323,8 @@ Rcpp::NumericMatrix sample_points(Rcpp::Nullable<Rcpp::Reference> P,
         }
         case 3: {
             // Zonotope
-            ZP.init(dim, Rcpp::as<MT>(Rcpp::as<Rcpp::Reference>(P).field("G")),
-                    VT::Ones(Rcpp::as<MT>(Rcpp::as<Rcpp::Reference>(P).field("G")).rows()));
+            ZP.init(dim, Rcpp::as<MT>(P.slot("G")),
+                    VT::Ones(Rcpp::as<MT>(P.slot("G")).rows()));
 
             if (!set_starting_point || (!set_mode && gaussian)) {
                 InnerBall = ZP.ComputeInnerBall();
@@ -329,10 +343,10 @@ Rcpp::NumericMatrix sample_points(Rcpp::Nullable<Rcpp::Reference> P,
             // Intersection of two V-polytopes
             Vpolytope VP1;
             Vpolytope VP2;
-            VP1.init(dim, Rcpp::as<MT>(Rcpp::as<Rcpp::Reference>(P).field("V1")),
-                     VT::Ones(Rcpp::as<MT>(Rcpp::as<Rcpp::Reference>(P).field("V1")).rows()));
-            VP2.init(dim, Rcpp::as<MT>(Rcpp::as<Rcpp::Reference>(P).field("V2")),
-                     VT::Ones(Rcpp::as<MT>(Rcpp::as<Rcpp::Reference>(P).field("V2")).rows()));
+            VP1.init(dim, Rcpp::as<MT>(P.slot("V1")),
+                     VT::Ones(Rcpp::as<MT>(P.slot("V1")).rows()));
+            VP2.init(dim, Rcpp::as<MT>(P.slot("V2")),
+                     VT::Ones(Rcpp::as<MT>(P.slot("V2")).rows()));
             VPcVP.init(VP1, VP2);
 
             if (!VPcVP.is_feasible()) throw Rcpp::exception("Empty set!");
@@ -349,10 +363,10 @@ Rcpp::NumericMatrix sample_points(Rcpp::Nullable<Rcpp::Reference> P,
         }
     }
 
-    switch (type) {
+    switch (type_num) {
         case 1: {
             sample_from_polytope(HP, rng, randPoints, walkL, numpoints, gaussian, a, L, boundary, StartingPoint, nburns,
-                   set_L, cdhr, rdhr, billiard, ball_walk);
+                                 set_L, cdhr, rdhr, billiard, ball_walk);
             break;
         }
         case 2: {
@@ -376,7 +390,6 @@ Rcpp::NumericMatrix sample_points(Rcpp::Nullable<Rcpp::Reference> P,
     MT RetMat(dim, numpoints);
     unsigned int jj = 0;
 
-
     for (typename std::list<Point>::iterator rpit = randPoints.begin(); rpit!=randPoints.end(); rpit++, jj++) {
         if (gaussian) {
 
